;; Generated package description from indent-bars.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "indent-bars" "1.0.0.0.20260417.181527" "Highlight indentation with bars" '((emacs "27.1") (compat "30")) :commit "09f83c4ef8aaa654bd8ffeff0427051be6e31924" :authors '(("J.D. Smith" . "jdtsmith+elpa@gmail.com")) :maintainer '("J.D. Smith" . "jdtsmith+elpa@gmail.com") :keywords '("convenience") :url "https://github.com/jdtsmith/indent-bars")
